# unittest-ft

Run tests in parallel with free threading

[![version](https://img.shields.io/pypi/v/unittest-ft.svg)](https://pypi.org/project/unittest-ft)
[![license](https://img.shields.io/pypi/l/unittest-ft.svg)](https://github.com/amyreese/unittest-ft/blob/main/LICENSE)


Install
-------

```shell-session
$ pip install unittest-ft
```


Usage
-----

```py
import unittest_ft
```


License
-------

unittest-ft is copyright Amethyst Reese, and licensed under the MIT license.